package llh.svs.core.services.schedule

import gaf3.core.data.ErrorResult
import gaf3.core.data.PageParam
import gaf3.core.data.PagedData
import llh.svs.core.services.schedule.domain.ScheduleTaskForm
import llh.svs.core.services.schedule.entity.SvsScheduleTask
import llh.svs.core.services.schedule.service.SvsScheduleService
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.ApplicationContext
import org.springframework.web.bind.annotation.*

@RestController
@RequestMapping(path = ["/svs/schedule"])
class ScheduleTaskController {

    @Autowired
    lateinit var service: SvsScheduleService

    @Autowired
    lateinit var ctx: ApplicationContext

    @PostMapping(path = ["/item"])
    fun create(@RequestBody form: ScheduleTaskForm): SvsScheduleTask {
        return service.create(form)
    }

    @PostMapping(path = ["/item/{id}"])
    fun update(@PathVariable("id") id: String, @RequestBody form: ScheduleTaskForm): SvsScheduleTask {
        return service.update(id, form)
    }

    @GetMapping(path = ["/items"])
    fun find(filter: SvsScheduleTask, pageParam: PageParam, exact: Boolean?): PagedData<SvsScheduleTask> {
        return service.find(filter, pageParam, exact ?: true)
    }

    @GetMapping(path = ["/item/{id}"])
    fun fetch(@PathVariable("id") id: String): SvsScheduleTask {
        return service.fetch(id)
    }

    @GetMapping(path = ["/task/cancel/{id}"])
    fun stopTask(@PathVariable("id") id: String): ErrorResult {
        service.cancel(id)
        return ErrorResult(0, "ok")
    }

    @GetMapping(path = ["/task/execute/{id}"])
    fun onceExecute(@PathVariable("id") id: String): ErrorResult {
        service.onceExecute(id)
        return ErrorResult(0, "ok")
    }

}
