package llh.svs.core.services.sys

import gaf3.core.data.ErrorResult
import gaf3.core.data.PagedData
import llh.svs.core.services.sys.domain.BackupFileResult
import llh.svs.core.services.sys.service.DBBackupService
import llh.svs.core.services.task.entity.SvsTaskLog
import llh.svs.core.util.FileDealTool
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.core.io.Resource
import org.springframework.http.ResponseEntity
import org.springframework.http.codec.multipart.FilePart
import org.springframework.util.Assert
import org.springframework.web.bind.annotation.*

@RestController
@RequestMapping(path = ["/svs/system/database"])
class DBBackupController {

    @Autowired
    lateinit var service: DBBackupService

    /**
     * 手动备份数据库
     */
    @GetMapping(path = ["/backup"])
    fun backupDatabase(@RequestParam filename: String?): ErrorResult {
        service.backupDatabase(filename)
        return ErrorResult(0, "ok")
    }

    /**
     * 获取所有备份文件名列表
     */
    @GetMapping(path = ["/filelist"])
    fun fileList(skip: Int?, limit: Int?): PagedData<BackupFileResult> {
        return service.getAllBackupFile(skip ?: 0, limit ?: 10)
    }

    /**
     * 下载备份文件，根据备份文件名下载
     */
    @GetMapping(path = ["/downbackup"])
    fun downloadBackupFile(filename: String?): ResponseEntity<Resource> {
        val file = service.downloadBackupFile(filename)
        return FileDealTool.getDownFileResponseEntity(file, file.nameWithoutExtension)
    }

    /**
     * 删除备份文件，根据文件名删除备份
     */
    @PostMapping(path = ["/delbackup"])
    fun deleteBackupFile(filename: String?): ErrorResult {
        service.deleteBackupFile(filename)
        return ErrorResult(0, "ok")
    }

    /**
     * 根据用户上传的备份文件恢复数据库
     */
    @PostMapping(path = ["/recovery"])
    fun recovery(@RequestPart(name = "file") file: FilePart): SvsTaskLog {
        val filename = file.filename()
        Assert.isTrue(filename.substring(filename.lastIndexOf('.')) == ".sql", "文件类型不合法")
        return service.createTask(FileDealTool.dealMultiFile(file))
    }

}
