package llh.svs.core.services.sys

import gaf3.core.data.ErrorResult
import llh.svs.core.services.sys.domain.ServerDate
import llh.svs.core.services.sys.service.ServerConfigService
import llh.svs.core.services.sys.service.ServerResService
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.codec.multipart.FilePart
import org.springframework.web.bind.annotation.*

/**
 * 服务器硬件配置
 */
@RestController
@RequestMapping(path = ["/svs/system"])
class SysConfigController {

    @Autowired
    lateinit var serverConfigService: ServerConfigService

    /**
     * 获取系统时间
     */
    @GetMapping(path = ["/time"])
    fun getServerTime(): ServerDate {
        return serverConfigService.getServerTime()
    }

    /**
     * 设置系统时间
     * @param date 时间格式：yyyy-MM-dd HH:mm:ss
     */
    @PostMapping(path = ["/time"])
    fun setServerTime(@RequestBody date: ServerDate): ErrorResult {
        serverConfigService.setServerTime(date)
        return ErrorResult(0, "ok")
    }

    /**
     * 重启服务器
     */
    @PostMapping(path = ["/reboot"])
    fun rebootServer() {
        serverConfigService.reboot()
    }

    /**
     * 设置license
     */
    @PostMapping(path = ["/license"])
    fun setLicense(@RequestPart(name = "file") file: FilePart): ErrorResult {
        // todo 接收license处理并验证license
        return ErrorResult(0, "ok")
    }
}
