package llh.svs.core.services.sys.service

import gaf3.core.exception.BusinessError
import llh.svs.core.services.sys.domain.ServerDate
import llh.svs.core.util.LinuxCmdExecutor
import org.slf4j.LoggerFactory
import org.springframework.stereotype.Service
import org.springframework.util.Assert

/**
 * 服务器硬件相关配置
 */
@Service
class ServerConfigService {

    /**
     * 获取系统时间
     */
    fun getServerTime(): ServerDate {
        val datetime = runCatching {
            val cmdString = "date '+%Y-%m-%d %H:%M:%S'"
            LinuxCmdExecutor.execute(cmdString).replace("\n", "")
        }.getOrElse {
            log.error("获取系统时间失败,原因:${it.message}")
            throw BusinessError(BusinessError.ERR_SERVICE_FAULT, "获取系统时间失败")
        }
        return ServerDate().apply {
            this.time = datetime
        }
    }

    /**
     * 设置系统时间
     */
    fun setServerTime(date: ServerDate) {
        Assert.hasText(date.time, "设置时间不可为空")
        val cmdString = "timedatectl set-ntp no && timedatectl set-time \"${date.time}\""
        runCatching {
            LinuxCmdExecutor.execute(cmdString)
        }.getOrElse {
            log.error("设置系统时间失败，原因：${it.message}")
            throw BusinessError(BusinessError.ERR_SERVICE_FAULT, "设置系统时间失败")
        }
    }

    /**
     * 服务器重启
     */
    fun reboot() {
        val cmdString = "reboot"
        LinuxCmdExecutor.execute(cmdString)
    }

    companion object {
        private val log = LoggerFactory.getLogger(ServerConfigService::class.java)
    }
}
