package llh.svs.core.services.task

import gaf3.core.data.PagedData
import gaf3.core.exception.BusinessError
import llh.svs.core.services.task.entity.SvsTaskLog
import llh.svs.core.services.task.service.SvsTaskLogService
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RequestParam
import org.springframework.web.bind.annotation.RestController

@RestController
@RequestMapping(path = ["/svs/task"])
class TaskController {

    @Autowired
    lateinit var service: SvsTaskLogService

    /**
     * 按ID查询任务信息
     * @param id 任务id
     * @return 查询成功返回任务信息
     * @throws BusinessError 查询不成功，描述异常情况。如：任务不存在
     */
    @GetMapping
    fun findById(@RequestParam("id") id: String): SvsTaskLog {
        return service.findById(id)
    }

    /**
     * 按条件查询列表（分页）
     * @param filter 任务信息
     * @param skip 当前页数
     * @param limit 每页条数
     * @return 成功返回任务列表
     */
    @GetMapping(path = ["/items"])
    fun find(filter: SvsTaskLog, skip: Int = 0, limit: Int = 20): PagedData<SvsTaskLog> {
        return service.find(filter, skip, limit)
    }
}
