package llh.svs.core.util

import jit.xms.core.services.util.domain.CpuInfo
import jit.xms.core.services.util.domain.DiskInfo
import jit.xms.core.services.util.domain.MemInfo
import oshi.SystemInfo
import oshi.util.Util

/**
 * 获取硬件信息工具类
 */
object SysHWInfoUtil {

    /**
     * 获取系统信息
     */
    private val systemInfo = SystemInfo()

    /**
     * 获取系统硬件信息
     */
    private val hardwareInfo = systemInfo.hardware

    /**
     * 获取操作系统信息
     */
    private val operationSystemInfo = systemInfo.operatingSystem

    /**
     * 获取CPU占用信息
     */
    fun getCpuInfo(): CpuInfo {
        val processor = hardwareInfo.processor
        val preSystemCpuLoadTicks = processor.systemCpuLoadTicks
        Util.sleep(300)
        return CpuInfo(
            cpuNum = processor.logicalProcessorCount,
            load = processor.getSystemCpuLoadBetweenTicks(preSystemCpuLoadTicks)
        )
    }

    /**
     * 获取内存信息
     */
    fun getMemInfo(): MemInfo {
        val memory = hardwareInfo.memory
        return MemInfo(total = memory.total, used = memory.total - memory.available, free = memory.available)
    }

    /**
     * 获取磁盘信息
     */
    fun getDiskInfo(): List<DiskInfo> {
        val fileSystem = operationSystemInfo.fileSystem
        return fileSystem.fileStores.map {
            DiskInfo(name = it.name, typeName = it.type, total = it.totalSpace, free = it.freeSpace, volume = it.volume)
        }
    }
}
